@@ -1,6 +1,10 @@
 import logging
-import urllib2
-from urllib import urlencode
+import urllib
+try:
+    from urllib.parse import urlencode
+except ImportError:
+    # Python 2.x compatible import
+    from urllib import urlencode
 
 from wtforms.validators import ValidationError
 
@@ -26,16 +30,16 @@ class Recaptcha(object):
         """Performs a call to reCaptcha API with given params"""
         data = []
         if proxy:
-            proxy_handler = urllib2.ProxyHandler({'http': proxy})
-            opener = urllib2.build_opener(proxy_handler)
-            urllib2.install_opener(opener)
+            proxy_handler = urllib.request.ProxyHandler({'http': proxy})
+            opener = urllib.request.build_opener(proxy_handler)
+            urllib.request.install_opener(opener)
 
         try:
-            response = urllib2.urlopen('http://www.google.com/recaptcha/api/verify',
+            response = urllib.request.urlopen('http://www.google.com/recaptcha/api/verify',
                     data=urlencode(params))
             data = response.read().splitlines()
             response.close()
-        except Exception, e:
+        except Exception as e:
             logging.error(str(e))
             raise ValidationError(self.errors['recaptcha-not-reachable'])
 
